betty.serde.dump module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.serde.dump module

An API to produce serializable data dumps.

betty.serde.dump.Dump: TypeAlias = bool | int | float | str | None | collections.abc.MutableSequence['Dump'] | collections.abc.MutableMapping[str, 'Dump']

  A serialized dump.

betty.serde.dump.DumpMapping

  A dump which is a mapping whose keys are strings and values are serialized dumps.

  alias of `MutableMapping`[`str`, `_DumpT`]

betty.serde.dump.DumpSequence

  A dump which is a sequence whose values are serialized dumps.

  alias of `MutableSequence`[`_DumpT`]

class betty.serde.dump.Dumpable

  Bases: `ABC`

  Instances can be produce serialized data dumps of `self`.

  abstract dump() → bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]

    Produce a serialized data dump of `self`.